@@ -1,6 +1,9 @@
 use std::process;
 
 fn main() {
+    if std::env::var("DOCS_RS").is_ok() {
+        return;
+    }
     let tango_lib = match pkg_config::probe_library("tango") {
         Ok(lib) => lib,
         Err(err) => { print!("{}---", err); process::exit(1); }
